@@ -8,6 +8,9 @@ instance Data a => Uniplate a where
     descend = descendData $ fromOracle answer
         where answer = hitTest (undefined :: a) (undefined :: a)
 
+    descendM = descendDataM $ fromOracle answer
+        where answer = hitTest (undefined :: a) (undefined :: a)
+
 instance (Data a, Data b, Uniplate b) => Biplate a b where
     biplate = biplateData $ fromOracle answer
         where answer = hitTest (undefined :: a) (undefined :: b)
@@ -15,3 +18,5 @@ instance (Data a, Data b, Uniplate b) => Biplate a b where
     descendBi = descendBiData $ fromOracle answer
         where answer = hitTest (undefined :: a) (undefined :: b)
 
+    descendBiM = descendBiDataM $ fromOracle answer
+        where answer = hitTest (undefined :: a) (undefined :: b)
