@@ -22,7 +22,7 @@ import Control.Monad(liftM)
 import Data.Traversable
 import Prelude hiding (mapM)
 
-import Data.Generics.PlateInternal
+import Data.Generics.Uniplate.Internal.Utils
 import Data.Generics.Str
 import Data.Generics.UniplateStr
 
